"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _PackageStorage = _interopRequireDefault(require("./PackageStorage"));
var _utils = require("./utils");
var _db = _interopRequireDefault(require("./db"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
class RedisStorage {
  constructor(config, options, redisClient) {
    _defineProperty(this, "config", void 0);
    _defineProperty(this, "version", void 0);
    _defineProperty(this, "logger", void 0);
    _defineProperty(this, "redisClient", void 0);
    _defineProperty(this, "db", void 0);
    this.config = config;
    this.logger = options.logger;
    if (redisClient !== undefined) this.redisClient = redisClient;else this.redisClient = (0, _utils.redisCreateClient)(this.config, this.logger);
    this.db = new _db.default(this.redisClient, this.logger);
  }
  async getSecret() {
    return this.db.getSecret();
  }
  async setSecret(secret) {
    return await this.redisClient.set(_utils.REDIS_KEY.secret, secret);
  }

  /**
   * Add a new element.
   * @param {*} name
   * @return {Error|*}
   */
  add(name, callback) {
    this.db.add(name).then(() => callback(null)).catch(err => callback(err));
  }

  /**
   * Perform a search in your registry
   * @param onPackage
   * @param onEnd
   * @param validateName
   */
  search(onPackage, onEnd, validateName) {
    this.db.search(validateName).then(pkgs => Promise.all(pkgs.map(pkg => this.getStat(pkg, onPackage)))).then(() => {
      onEnd(null);
    }).catch(err => {
      onEnd(err);
    });
  }

  /**
   * Get the stat object to feed onSearchPackage callback. A stat object is an index-like object with less memory and bandwidth cost.
   * @param name
   * @param onPackage
   */
  async getStat(name, onPackage) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const stat = await this.db.getStat(name);
    return new Promise((resolve, reject) => {
      onPackage(stat, err => {
        // this.logger.error({ err }, '[verdaccio/redis] RedisStorage.getStat onPackage callback @{err}');
        if (err) {
          reject(err);
        } else {
          resolve();
        }
      });
    });
  }

  /**
   * Remove an element from the database.
   * @param {*} name
   * @return {Error|*}
   */
  remove(name, callback) {
    this.db.remove(name).then(() => callback(null)).catch(err => callback(err));
  }

  /**
   * Return all database elements.
   * @return {Array}
   */
  get(callback) {
    this.db.get().then(packages => callback(null, packages)).catch(err => callback(err));
  }

  /**
   * Create an instance of the `PackageStorage`
   * @param packageName
   */
  getPackageStorage(packageName) {
    return new _PackageStorage.default(this.config, packageName, this.logger, this.redisClient, this.db);
  }

  /**
   * All methods for npm token support
   * more info here https://github.com/verdaccio/verdaccio/pull/1427
   */

  saveToken(token) {
    return this.db.saveToken(token);
  }
  deleteToken(user, tokenKey) {
    return this.db.deleteToken(user, tokenKey);
  }
  readTokens(filter) {
    return this.db.readTokens(filter);
  }
}
exports.default = RedisStorage;