import { Logger, ILocalPackageManager, StorageUpdateCallback, PackageTransformer, StorageWriteCallback, CallbackAction, Package, ReadPackageCallback } from '@verdaccio/types';
import { UploadTarball, ReadTarball } from '@verdaccio/streams';
import Redis from "ioredis";
import { RedisOptions } from 'ioredis';
import Database from './db';
export default class StoragePluginManager implements ILocalPackageManager {
    logger: Logger;
    packageName: string;
    config: RedisOptions;
    redisClient: Redis;
    db: Database;
    constructor(config: RedisOptions, packageName: string, logger: Logger, redisClient: Redis, db: Database);
    /**
     * Handle a metadata update and
     * @param pkgName
     * @param updateHandler
     * @param onWrite
     * @param transformPackage
     * @param callback
     */
    updatePackage(pkgName: string, updateHandler: StorageUpdateCallback, onWrite: StorageWriteCallback, transformPackage: PackageTransformer, callback: CallbackAction): void;
    /**
     * Delete a specific file (tarball or package.json)
     * @param fileName
     * @param callback
     */
    deletePackage(fileName: string, callback: CallbackAction): void;
    private deletePackageAsync;
    /**
     * Delete a package (folder, path)
     * This happens after all versions ar tarballs have been removed.
     * @param callback
     */
    removePackage(callback: CallbackAction): void;
    private removePackageAsync;
    /**
     * Publish a new package (version).
     * @param pkgName
     * @param pkg
     * @param callback
     */
    createPackage(pkgName: string, pkg: Package, callback: CallbackAction): void;
    private createPackageAsync;
    /**
     * Perform write an object to the storage.
     * Similar to updatePackage but without middleware handlers
     * @param pkgName package name
     * @param pkg package metadata
     * @param callback
     */
    savePackage(pkgName: string, pkg: Package, callback: CallbackAction): void;
    private savePackageAsync;
    /**
     * Read a package from storage
     * @param pkgName package name
     * @param callback
     */
    readPackage(pkgName: string, callback: ReadPackageCallback): void;
    readPackageAsync(pkgName: string): Promise<Package>;
    /**
     * Create writtable stream (write a tarball)
     * @param fileName
     */
    writeTarball(fileName: string): UploadTarball;
    /**
     * Create a readable stream (read a from a tarball)
     * @param fileName
     */
    readTarball(fileName: string): ReadTarball;
}
