import { Logger, Token, TokenFilter } from '@verdaccio/types';
import Redis from "ioredis";
import { PackageStat } from '../types';
/**
 * Database of Verdaccio. It's actually pretty simple as it only contains a secret
 * and a list of packages stored in Verdaccio.
 */
export default class Database {
    private redisClient;
    private logger;
    constructor(redisClient: Redis, logger: Logger);
    /**
     * Get the secret from the database
     */
    getSecret(): Promise<string>;
    /**
     * Update the secret in the database
     *
     * @param secret
     */
    setSecret(secret: string): Promise<void>;
    /**
     * Search for packages based on the validation function
     *
     * @param validate
     */
    search(validate: (name: string) => boolean): Promise<string[]>;
    /**
     * Get stat object for package name
     *
     * @param name
     */
    getStat(name: string): Promise<PackageStat>;
    /**
     * Set stat object for package name
     *
     * @param name
     */
    setStat(name: string, date?: Date): Promise<void>;
    /**
     * Get all the packages in the database
     */
    get(): Promise<string[]>;
    /**
     * Add the given package to the database
     *
     * @param name
     */
    add(name: string): Promise<void>;
    /**
     * Remove the given package from the database
     *
     * @param name
     */
    remove(name: string): Promise<void>;
    /**
     * Save token to the database
     *
     * @param name
     */
    saveToken(token: Token): Promise<void>;
    /**
     * Delete token from the database
     *
     * @param name
     */
    deleteToken(user: string, tokenKey: string): Promise<void>;
    /**
     * Read tokens from the database
     *
     * @param name
     */
    readTokens(filter: TokenFilter): Promise<Token[]>;
}
