import { Logger, Callback, IPluginStorage, PluginOptions, IPackageStorage, TokenFilter, Token, Config, onEndSearchPackage, onSearchPackage, onValidatePackage } from '@verdaccio/types';
import Redis from "ioredis";
import { RedisConfig } from '../types/index';
import Database from './db';
export default class RedisStorage implements IPluginStorage<RedisConfig> {
    config: RedisConfig & Config;
    version?: string;
    logger: Logger;
    redisClient: Redis;
    db: Database;
    constructor(config: RedisConfig, options: PluginOptions<RedisConfig>, redisClient?: Redis);
    getSecret(): Promise<string>;
    setSecret(secret: string): Promise<any>;
    /**
     * Add a new element.
     * @param {*} name
     * @return {Error|*}
     */
    add(name: string, callback: Callback): void;
    /**
     * Perform a search in your registry
     * @param onPackage
     * @param onEnd
     * @param validateName
     */
    search(onPackage: onSearchPackage, onEnd: onEndSearchPackage, validateName: onValidatePackage): void;
    /**
     * Get the stat object to feed onSearchPackage callback. A stat object is an index-like object with less memory and bandwidth cost.
     * @param name
     * @param onPackage
     */
    private getStat;
    /**
     * Remove an element from the database.
     * @param {*} name
     * @return {Error|*}
     */
    remove(name: string, callback: Callback): void;
    /**
     * Return all database elements.
     * @return {Array}
     */
    get(callback: Callback): void;
    /**
     * Create an instance of the `PackageStorage`
     * @param packageName
     */
    getPackageStorage(packageName: string): IPackageStorage;
    /**
     * All methods for npm token support
     * more info here https://github.com/verdaccio/verdaccio/pull/1427
     */
    saveToken(token: Token): Promise<void>;
    deleteToken(user: string, tokenKey: string): Promise<void>;
    readTokens(filter: TokenFilter): Promise<Token[]>;
}
