#!/usr/bin/env node
"use strict";

var _loglevel = _interopRequireDefault(require("loglevel"));
var _commander = require("commander");
var _projectVersion = _interopRequireDefault(require("project-version"));
var _commands = require("./commands");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const runCommand = async function (callback) {
  try {
    await callback();
    process.exit(0);
  } catch (err) {
    if (err instanceof Error) {
      _loglevel.default.error('Error: ' + err.message);
    } else {
      _loglevel.default.error('Error: ' + String(err));
    }
    process.exit(1);
  }
};
_commander.program.version(_projectVersion.default).description('verdaccio-redis-storage CLI').option('--config <path>', 'specify the path of Verdaccio configuration file').option('--host <host>', 'Redis host').option('--port <port>', 'Redis port').option('--url <url>', 'Redis protocol URL. i.e. redis://user:pass@127.0.0.1:6380/2').option('--socket <socket>', 'Socket path. i.e. /tmp/redis.sock').option('--password <password>', 'Redis password').option('--db <db>', 'Redis db').option('--prefix <prefix>', 'Redis prefix');
_commander.program.command('dump <dir>').description('dump Redis storage to dir').option('--no-tarball', 'ignore tarball files').option('--dbname', 'database filename (default: .verdaccio-db.json)').action(async function (dir, cmd) {
  const opts = _commander.program.opts();
  await runCommand(async () => {
    await (0, _commands.dump)(dir, opts);
  });
});
_commander.program.command('restore <dir>').description('restore Redis storage from dir').option('--no-tarball', 'ignore tarball files').option('--dbname', 'database filename (default: .verdaccio-db.json)').option('--scan', 'scan package.json to fill database').action(async function (dir, cmd) {
  await runCommand(async () => {
    await (0, _commands.restore)(dir, cmd);
  });
});

// prompt for invalid command
_commander.program.on('command:*', function () {
  _loglevel.default.error(`invalid command: ${_commander.program.args.join(' ')}
see --help for a list of available commands`);
  process.exit(1);
});
_commander.program.parse(process.argv);

// print help if no command is given
if (!_commander.program.args.length) _commander.program.help();